@@ -1,5 +1,5 @@
 package Consul::API::Catalog;
-$Consul::API::Catalog::VERSION = '0.003';
+$Consul::API::Catalog::VERSION = '0.004';
 use namespace::autoclean;
 
 use Moo::Role;
@@ -63,7 +63,7 @@ sub node {
 }
 
 package Consul::API::Catalog::ShortNode;
-$Consul::API::Catalog::ShortNode::VERSION = '0.003';
+$Consul::API::Catalog::ShortNode::VERSION = '0.004';
 use Moo;
 use Types::Standard qw(Str);
 
@@ -71,7 +71,7 @@ has name    => ( is => 'ro', isa => Str, init_arg => 'Node',    required => 1 );
 has address => ( is => 'ro', isa => Str, init_arg => 'Address', required => 1 );
 
 package Consul::API::Catalog::Service;
-$Consul::API::Catalog::Service::VERSION = '0.003';
+$Consul::API::Catalog::Service::VERSION = '0.004';
 use Moo;
 use Types::Standard qw(Str Int ArrayRef);
 
@@ -80,10 +80,10 @@ has id      => ( is => 'ro', isa => Str,           init_arg => 'ServiceID',   re
 has port    => ( is => 'ro', isa => Int,           init_arg => 'ServicePort', required => 1 );
 has node    => ( is => 'ro', isa => Str,           init_arg => 'Node',        required => 1 );
 has address => ( is => 'ro', isa => Str,           init_arg => 'Address',     required => 1 );
-has tags    => ( is => 'ro', isa => ArrayRef[Str], init_arg => 'ServiceTags', required => 1, coerce => sub { $_[0] // [] } );
+has tags    => ( is => 'ro', isa => ArrayRef[Str], init_arg => 'ServiceTags', required => 1, coerce => sub { $_[0] || [] } );
 
 package Consul::API::Catalog::Node;
-$Consul::API::Catalog::Node::VERSION = '0.003';
+$Consul::API::Catalog::Node::VERSION = '0.004';
 use Moo;
 use Types::Standard qw(HashRef);
 use Type::Utils qw(class_type);
